@@ -2,7 +2,7 @@
 extern crate test;
 
 use {
-    solana_ledger::entry::{next_entry_mut, Entry, EntrySlice},
+    solana_entry::entry::{next_entry_mut, Entry, EntrySlice},
     solana_sdk::{
         hash::{hash, Hash},
         signature::{Keypair, Signer},
